
*USNO Circular 179* by George H. Kaplan, October 2005

    http://aa.usno.navy.mil/publications/docs/Circular_179.php

    My favorite introduction to how the International Astronomical Union
    responded in 1997 and 2000 to the problems with the old J2000 system
    by adopting the ICRS and a new Earth rotation model.  Thanks to
    Kaplan’s explanations, I finally understood the maneuvers of the
    USNO’s freely available NOVAS library when dealing with dates and
    coordinate systems, and I was able to perform the same calculations
    correctly in Skyfield.  It also provided a useful introduction to
    the JPL ephemerides that NOVAS uses.

http://aa.usno.navy.mil/software/novas/novas_f/NOVAS_F3.1_Guide.pdf

http://eclipse.gsfc.nasa.gov/SEcat5/deltat.html
==
http://eclipse.gsfc.nasa.gov/SEhelp/deltat2004.html

http://eclipse.gsfc.nasa.gov/SEhelp/deltatpoly2004.html # the polynomial

http://eclipse.gsfc.nasa.gov/SEhelp/deltaT2.html     # out of date

http://adsabs.harvard.edu/full/2004JHA....35..327M

http://articles.adsabs.harvard.edu/cgi-bin/nph-iarticle_query?2004JHA....35..327M&defaultprint=YES&filetype=.pdf

http://articles.adsabs.harvard.edu/cgi-bin/nph-iarticle_query?2004JHA....35..327M&data_type=PDF_HIGH&type=PRINTER&filetype=.pdf

http://asa.usno.navy.mil/
http://asa.usno.navy.mil/SecK/DeltaT.html

http://eclipse.gsfc.nasa.gov/SEpubs/5MCSE.html

http://eclipse.gsfc.nasa.gov/5MCSE/5MCSE-Text11.pdf

http://maia.usno.navy.mil/
http://maia.usno.navy.mil/ser7/deltat.data
http://maia.usno.navy.mil/ser7/deltat.preds
http://maia.usno.navy.mil/ser7/historic_deltat.data

http://www.iers.org/IERS/EN/DataProducts/EarthOrientationData/eop.html


ftp://ssd.jpl.nasa.gov/pub/eph/planets/ioms/  !
